#!/usr/bin/env python

"A form submission test."

import WebStack.Generic

class FormResource:

    """
    A resource which handles incoming form submissions.
    """

    def respond(self, trans):

        """
        Examine the incoming request, decoding the form information.
        """

        # NOTE: Some frameworks do not pass in the content type.

        content_type = trans.get_content_type()
        input = trans.get_request_stream()
        received_data = input.read()

        # NOTE: Send the appropriate kind of response.

        trans.set_content_type(WebStack.Generic.ContentType("text/html"))
        out = trans.get_response_stream()
        out.write("""
<html>
  <head>
    <title>Form Test</title>
  </head>
  <body>
    <h1>Form Test</h1>
    <h2>Normal</h2>
    <form method="post" action="">
      <input name="x" type="text" value="1"/><br/>
      <input name="x" type="text" value="2"/><br/>
      <input name="y" type="text" value="3"/><br/>
      <input name="f" type="file"/><br/>
      <input name="send" type="submit" value="Send!"/>
    </form>
    <h2>Multipart</h2>
    <form method="post" action="" enctype="multipart/form-data">
      <input name="x" type="text" value="1"/><br/>
      <input name="x" type="text" value="2"/><br/>
      <input name="y" type="text" value="3"/><br/>
      <input name="f" type="file"/><br/>
      <input name="send" type="submit" value="Send!"/>
    </form>
    <h2>Content Type</h2>
    <p>%s</p>
    <h2>Received Data</h2>
    <p>Start</p>
    <pre>%s</pre>
    <p>Stop</p>
  </body>
</html>
""" % (content_type.content_type, received_data.replace("<", "&lt;").replace(">", "&gt;").replace("&", "&amp;")))

# vim: tabstop=4 expandtab shiftwidth=4
